# Version info: R 2.14.1, Biobase 2.15.3, GEOquery 2.23.2, limma 3.10.1
# R scripts generated  Thu Jan 29 19:29:55 EST 2015

## Adapted from a script generated by GEO2R
## http://www.ncbi.nlm.nih.gov/geo/info/geo2r.html
## Zachary King, 2015

################################################################
#   Differential expression analysis with limma
## library(Biobase)
library(GEOquery)
library(limma)

# load series and platform data from GEO

gset <- getGEO("GSE41113", GSEMatrix = TRUE)
if (length(gset) > 1) idx <- grep("GPL16098", attr(gset, "names")) else idx <- 1
gset <- gset[[idx]]

# make proper column names to match toptable 
fvarLabels(gset) <- make.names(fvarLabels(gset))

# group names for all samples

sml <- c("siMock untreated", "siMock untreated", "siMock untreated",
         "siMock 0.5 mM But", "siMock 0.5 mM But", "siMock 0.5 mM But",
         "siMock 2.0 mM But", "siMock 2.0 mM But", "siMock 2.0 mM But",
         "siMock 5.0 mM But", "siMock 5.0 mM But", "siMock 5.0 mM But",
         "siACL untreated", "siACL untreated", "siACL untreated",
         "siACL 0.5 mM But", "siACL 0.5 mM But", "siACL 0.5 mM But",
         "siACL 2.0 mM But", "siACL 2.0 mM But", "siACL 2.0 mM But",
         "siACL 5.0 mM But", "siACL 5.0 mM But", "siACL 5.0 mM But");

# log2 transform
## ex <- exprs(gset)
## qx <- as.numeric(quantile(ex, c(0., 0.25, 0.5, 0.75, 0.99, 1.0), na.rm=T))
## LogC <- (qx[5] > 100) ||
##           (qx[6]-qx[1] > 50 && qx[2] > 0) ||
##           (qx[2] > 0 && qx[2] < 1 && qx[4] > 1 && qx[4] < 2)
## if (LogC) { ex[which(ex <= 0)] <- NaN
##   exprs(gset) <- log2(ex) }

# set up the data and proceed with analysis
fl <- as.factor(sml)
gset$description <- fl
design <- model.matrix(~ description + 0, gset)
colnames(design) <- levels(fl)
fit <- lmFit(gset, design)



## new code to save just coefficients:
coefficients <- fit$coefficients
## get synonyms
# load the annotation database
library(org.Hs.eg.db)
table = toTable(org.Hs.egSYMBOL2EG)
merged <- merge(coefficients, table, by.y="symbol", by.x="row.names")
row.names(merged) <- merged[,"gene_id"]
## save the tables as comparisons
write.table(merged[,c("siMock untreated", "siACL untreated")],
            file='donohoe_untreated_siMock_siACL.csv', col.names=NA, sep=",")
write.table(merged[,c("siMock untreated", "siMock 5.0 mM But")],
            file='donohoe_siMock_untreated_5mM.csv', col.names=NA, sep=",")
write.table(merged[,c("siACL untreated", "siACL 5.0 mM But")],
            file='donohoe_siACL_untreated_5mM.csv', col.names=NA, sep=",")



## cont.matrix <- makeContrasts(G7-G0, G1-G0, G2-G1, G3-G2, G4-G3, G5-G4, G6-G5, G7-G6, levels=design)
## fit2 <- contrasts.fit(fit, cont.matrix)
## fit2 <- eBayes(fit2, 0.01)

## tT <- topTable(fit2, adjust="fdr", sort.by="B", number=250)

## tT <- subset(tT, select=c("ID","adj.P.Val","P.Value","F","ORF"))
## write.table(tT, file=stdout(), row.names=F, sep="\t")

################################################################
#   Boxplot for selected GEO samples
## library(Biobase)
## library(GEOquery)

## # load series and platform data from GEO

## gset <- getGEO("GSE41113", GSEMatrix =TRUE)
## if (length(gset) > 1) idx <- grep("GPL16098", attr(gset, "names")) else idx <- 1
## gset <- gset[[idx]]

## # group names for all samples in a series
## sml <- c("G0","G0","G0","G1","G1","G1","G2","G2","G2","G3","G3","G3","G4","G4","G4","G5","G5","G5","G6","G6","G6","G7","G7","G7")

## # order samples by group
## ex <- exprs(gset)[ , order(sml)]

## sml <- sml[order(sml)]
## fl <- as.factor(sml)
## labels <- c("untreated","but0p5","but2","but5","acl_untreated","acl_but0p5","acl_but2","acl_but5")

## # set parameters and draw the plot
## palette(c("#dfeaf4","#f4dfdf","#f2cb98","#dcdaa5","#dff4e4","#f4dff4","#c7ff9d","#f3f388", "#AABBCC"))
## dev.new(width=4+dim(gset)[[2]]/5, height=6)
## par(mar=c(2+round(max(nchar(sampleNames(gset)))/2),4,2,1))
## title <- paste ("GSE41113", '/', annotation(gset), " selected samples", sep ='')
## boxplot(ex, boxwex=0.6, notch=T, main=title, outline=FALSE, las=2, col=fl)
## legend("topleft", labels, fill=palette(), bty="n")
